# CHANGELOG



## v0.1.4 (2025-04-15)

###  

* Use `pypa/gh-action-pypi-publish@v1.12.4` ([`8af5fea`](https://github.com/icecube/voka/commit/8af5fea7dccc7406f6c61e1eda43cda3a9931b35))


## v0.1.3 (2024-11-18)

###  

* rm `samples.py` (use github.com/icecube/simprod-histogram) ([`93a36dd`](https://github.com/icecube/voka/commit/93a36dd34bfd8930712f2866635d1ed8fd5169ca))


## v0.1.2 (2024-11-18)

###  

* Publish to PyPI (Followup 2) ([`184cf02`](https://github.com/icecube/voka/commit/184cf026290e14bb00ada883b967063797491d70))


## v0.1.1 (2024-11-18)

###  

* Merge remote-tracking branch &#39;origin/main&#39; ([`3daa122`](https://github.com/icecube/voka/commit/3daa122c198a50433295194a23852399f5619cd2))

* Use `pypa/gh-action-pypi-publish@v1.8.14` ([`f5f55cd`](https://github.com/icecube/voka/commit/f5f55cd6152fd96e966f6f7a3c702990dab79566))


## v0.1.0 (2024-11-18)

### [minor]

* Publish to PyPI (Followup) [minor] ([`bb96755`](https://github.com/icecube/voka/commit/bb9675546f977a579cc31003c2998f4eaf493052))


## v0.0.1 (2024-11-18)

###  

* CI: Use `v9.8.1` Packages for Publishing ([`a09db9b`](https://github.com/icecube/voka/commit/a09db9b661ae258cc3c85e5fc50f615008fc2651))

* Add CI: Followup (#12) ([`8bbb25d`](https://github.com/icecube/voka/commit/8bbb25dc7ea833fe065c6d650b82a16c9adba932))

* Add CI: Tests and PyPI Publishing (#11)

Co-authored-by: github-actions &lt;github-actions@github.com&gt; ([`fbb8b1e`](https://github.com/icecube/voka/commit/fbb8b1e91c211b2943d3b8c79bd151caeff81797))

* Merge pull request #10 from icecube/dependabot/pip/pillow-10.3.0

Bump pillow from 10.2.0 to 10.3.0 ([`cef1ec2`](https://github.com/icecube/voka/commit/cef1ec28e6a360c7a60b8105b7cc78c72e922629))

* Bump pillow from 10.2.0 to 10.3.0

Bumps [pillow](https://github.com/python-pillow/Pillow) from 10.2.0 to 10.3.0.
- [Release notes](https://github.com/python-pillow/Pillow/releases)
- [Changelog](https://github.com/python-pillow/Pillow/blob/main/CHANGES.rst)
- [Commits](https://github.com/python-pillow/Pillow/compare/10.2.0...10.3.0)

---
updated-dependencies:
- dependency-name: pillow
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`aa262bb`](https://github.com/icecube/voka/commit/aa262bb9b9fc83b96f8cbc5f61a1693925a6823a))

* Merge pull request #9 from icecube/dependabot/pip/pillow-10.2.0

Bump pillow from 10.0.1 to 10.2.0 ([`02e8fda`](https://github.com/icecube/voka/commit/02e8fdae8967048c8a88fc119f27a5116c89fd7d))

* Bump pillow from 10.0.1 to 10.2.0

Bumps [pillow](https://github.com/python-pillow/Pillow) from 10.0.1 to 10.2.0.
- [Release notes](https://github.com/python-pillow/Pillow/releases)
- [Changelog](https://github.com/python-pillow/Pillow/blob/main/CHANGES.rst)
- [Commits](https://github.com/python-pillow/Pillow/compare/10.0.1...10.2.0)

---
updated-dependencies:
- dependency-name: pillow
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`16b7ce4`](https://github.com/icecube/voka/commit/16b7ce4d75f66044168592ed76c5fb8f96da205c))

* Merge pull request #8 from icecube/dependabot/pip/fonttools-4.43.0

Bump fonttools from 4.28.5 to 4.43.0 ([`81eb492`](https://github.com/icecube/voka/commit/81eb4927a960fa7497615b308411c44c79e3819f))

* Bump fonttools from 4.28.5 to 4.43.0

Bumps [fonttools](https://github.com/fonttools/fonttools) from 4.28.5 to 4.43.0.
- [Release notes](https://github.com/fonttools/fonttools/releases)
- [Changelog](https://github.com/fonttools/fonttools/blob/main/NEWS.rst)
- [Commits](https://github.com/fonttools/fonttools/compare/4.28.5...4.43.0)

---
updated-dependencies:
- dependency-name: fonttools
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`f32f3f9`](https://github.com/icecube/voka/commit/f32f3f93704e876aa6c0a75442f120683b796332))

* Merge pull request #7 from icecube/dependabot/pip/pillow-10.0.1

Bump pillow from 9.3.0 to 10.0.1 ([`62df3c3`](https://github.com/icecube/voka/commit/62df3c34ec0790153adc5403ca620d799cf059a2))

* Bump pillow from 9.3.0 to 10.0.1

Bumps [pillow](https://github.com/python-pillow/Pillow) from 9.3.0 to 10.0.1.
- [Release notes](https://github.com/python-pillow/Pillow/releases)
- [Changelog](https://github.com/python-pillow/Pillow/blob/main/CHANGES.rst)
- [Commits](https://github.com/python-pillow/Pillow/compare/9.3.0...10.0.1)

---
updated-dependencies:
- dependency-name: pillow
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`2967a12`](https://github.com/icecube/voka/commit/2967a12dcb45adbb11a4cd14c3fc9b5d760c1c19))

* Merge pull request #6 from icecube/dependabot/pip/scipy-1.10.0

Bump scipy from 1.7.3 to 1.10.0 ([`bd0f9cd`](https://github.com/icecube/voka/commit/bd0f9cdd294429a84adfe09e032355cb79d33861))

* Bump scipy from 1.7.3 to 1.10.0

Bumps [scipy](https://github.com/scipy/scipy) from 1.7.3 to 1.10.0.
- [Release notes](https://github.com/scipy/scipy/releases)
- [Commits](https://github.com/scipy/scipy/compare/v1.7.3...v1.10.0)

---
updated-dependencies:
- dependency-name: scipy
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`9c9f6cd`](https://github.com/icecube/voka/commit/9c9f6cd19699165cfdc45c41d7a5c6113827e53a))

* Merge pull request #5 from icecube/dependabot/pip/pillow-9.3.0

Bump pillow from 9.0.1 to 9.3.0 ([`11cf3b5`](https://github.com/icecube/voka/commit/11cf3b5099cd71ee20972cdcd34cf6b2156003fc))

* Bump pillow from 9.0.1 to 9.3.0

Bumps [pillow](https://github.com/python-pillow/Pillow) from 9.0.1 to 9.3.0.
- [Release notes](https://github.com/python-pillow/Pillow/releases)
- [Changelog](https://github.com/python-pillow/Pillow/blob/main/CHANGES.rst)
- [Commits](https://github.com/python-pillow/Pillow/compare/9.0.1...9.3.0)

---
updated-dependencies:
- dependency-name: pillow
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`2c77097`](https://github.com/icecube/voka/commit/2c77097a0f9a98a92be18f9646183ac205ff9825))

* latest hacks ([`e2143ab`](https://github.com/icecube/voka/commit/e2143ab3c1b4c18b9a760436769cf19994490a7e))

* cleaned up example script comparing voka to scipy two sample tests ([`fabb728`](https://github.com/icecube/voka/commit/fabb728367cd5de9997bb5b0c0e7f794472cce21))

* Merge pull request #4 from icecube/dependabot/pip/pillow-9.0.1

Bump pillow from 9.0.0 to 9.0.1 ([`d37dafe`](https://github.com/icecube/voka/commit/d37dafe7e1ac06ca21ebdc58680b616948bb02cd))

* Bump pillow from 9.0.0 to 9.0.1

Bumps [pillow](https://github.com/python-pillow/Pillow) from 9.0.0 to 9.0.1.
- [Release notes](https://github.com/python-pillow/Pillow/releases)
- [Changelog](https://github.com/python-pillow/Pillow/blob/main/CHANGES.rst)
- [Commits](https://github.com/python-pillow/Pillow/compare/9.0.0...9.0.1)

---
updated-dependencies:
- dependency-name: pillow
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`b623390`](https://github.com/icecube/voka/commit/b62339049d4f70af3e84f24aa0fe6d7d8df22860))

* Update README.md ([`be2cb03`](https://github.com/icecube/voka/commit/be2cb03a4086edfec16f2e1f95e9e3dcec808be0))

* Update README.md ([`866a839`](https://github.com/icecube/voka/commit/866a839907250b45ec27e9116ebfbdf7908cb29f))

* Update README.md ([`44a7d54`](https://github.com/icecube/voka/commit/44a7d546e7960753bd1157fd24ae01283ee1f1f4))

* Update README.md ([`62f672b`](https://github.com/icecube/voka/commit/62f672b4ffa72b8b2b5273a18ca1493890cd84cd))

* setup.py now reads from the requirements file so there is a single source of truth. ([`871eac5`](https://github.com/icecube/voka/commit/871eac5c148ef41756ce3db9497c55dd2ecaacfd))

* including histogram class and tests.  moved from cicada since this is a more appropriate location. ([`c0f0ee5`](https://github.com/icecube/voka/commit/c0f0ee5176dd3e07e4818ebf1dd5a6ac9a881dcc))

* updated requirements.txt ([`5f7e36c`](https://github.com/icecube/voka/commit/5f7e36ce99ff3aa903657d3a7b6a12f8455e40b7))

* very minor tweak to wording in documentation ([`46c9e85`](https://github.com/icecube/voka/commit/46c9e85de41752e6d526011ac6ca488d0c03fa05))

* Merge branch &#39;main&#39; of github.com:icecube/voka into main ([`21680b1`](https://github.com/icecube/voka/commit/21680b1ff3381b5cb300e0dd2ed6072f41e0a5a4))

* added a script with illustrates the basic concept. ([`d3d0a3d`](https://github.com/icecube/voka/commit/d3d0a3ddf463981af9cae2c96b10d4aa5f70cee2))

* don&#39;t import what you don&#39;t use. ([`831a481`](https://github.com/icecube/voka/commit/831a481f9e6e2db465f735ece31fba2070c7643b))

* change the ordering of the docs to match the method parameter order ([`0ab919b`](https://github.com/icecube/voka/commit/0ab919b50f85538e50865f513f653013cd7db108))

* make tools a module ([`c7e15b6`](https://github.com/icecube/voka/commit/c7e15b6aa3b7c5990716199e49d32751dcf1a4ee))

* Update README.md

Added a link to the coverage project. ([`3557080`](https://github.com/icecube/voka/commit/35570802db975161f753afa6e1e304a2e8dcbfad))

* Update README.md

Updated coverage results. ([`7b82306`](https://github.com/icecube/voka/commit/7b82306849d705f8b02c1d48ca0155f52b22a97f))

* Update README.md

Added an extra command that display coverage results. ([`f581f15`](https://github.com/icecube/voka/commit/f581f159c530a04b71f69cc7b8f3d0ad32019bf7))

* Update README.md

Added CV &#34;Continuous Validation&#34; to the list of things cicada does. ([`fb66f9e`](https://github.com/icecube/voka/commit/fb66f9ea7301d5877a28f0ddb829ca126ba90525))

* Update README.md

Cleaned up the intro by removing documentation that&#39;s duplicated below. ([`3a98fc0`](https://github.com/icecube/voka/commit/3a98fc0e7adb643ac924e4cdbcf47b541e17760a))

* Update README.md

Cleaned up the references section. ([`4273b3c`](https://github.com/icecube/voka/commit/4273b3ce47d692d095c6bb8a9cfe82ded5b40be9))

* Update README.md

Made it clear in the documentation that scipy is optional and not part of the core library. ([`9d3301b`](https://github.com/icecube/voka/commit/9d3301ba1f0296767bb2d7755c47fd313918eb30))

* Update README.md

Added a problem statement up front to give readers a clearer idea about what this project is for. ([`1d7b632`](https://github.com/icecube/voka/commit/1d7b632fbd83e1f51fd08f8db9cda5d6474333b9))

* Merge pull request #3 from icecube/dependabot/pip/numpy-1.21.0

Bump numpy from 1.18.1 to 1.21.0 ([`d4d9351`](https://github.com/icecube/voka/commit/d4d9351f40f2b9c32113ff13a840801ff601b436))

* Bump numpy from 1.18.1 to 1.21.0

Bumps [numpy](https://github.com/numpy/numpy) from 1.18.1 to 1.21.0.
- [Release notes](https://github.com/numpy/numpy/releases)
- [Changelog](https://github.com/numpy/numpy/blob/main/doc/HOWTO_RELEASE.rst.txt)
- [Commits](https://github.com/numpy/numpy/compare/v1.18.1...v1.21.0)

---
updated-dependencies:
- dependency-name: numpy
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`e9166b9`](https://github.com/icecube/voka/commit/e9166b9d234e32e122c8cc1c1274d4aa0adc18bf))

* added a setup.py to make this project pip installable. ([`23f18e8`](https://github.com/icecube/voka/commit/23f18e8a00b73595ad8218cd384ec4f660281576))

* replace function objects with functions.   being able to strinqize the name to use as a key via self.__name__ isn&#39;t a good enough reason. ([`29a5d44`](https://github.com/icecube/voka/commit/29a5d4439cf13d35e29b9308dcbf54c799be3b83))

* adding a script that compares two sample methods to voka. ([`e474205`](https://github.com/icecube/voka/commit/e4742054531267f13bc05bcdf5d5f002a3359325))

* adding a script that compares traditional two-sample methods available in scipy. ([`e6231ce`](https://github.com/icecube/voka/commit/e6231ceb272889dfec1e0957a3a63a12c6451557))

* adding useful utilities ([`d63d986`](https://github.com/icecube/voka/commit/d63d986f37a2eb090c198af168e77740cc9c7ccd))

* adding a function that runs two-sample stats from scipy. ([`39662f5`](https://github.com/icecube/voka/commit/39662f5ec808c6c98c9054e2bc8bfe579eb4492c))

* throw if there are no results ([`d31db77`](https://github.com/icecube/voka/commit/d31db77cf9407c334492e5c9606d85b942d5b181))

* ignoring data files like pickle and compressed I3. ([`65f1ee3`](https://github.com/icecube/voka/commit/65f1ee3b666edb7460c3884ea8f0f177d56152ae))

* updated readme with better dependency information provided by pylint. ([`5d41ada`](https://github.com/icecube/voka/commit/5d41ada9bc808a37a6c067361e3441fe26d37cb5))

* conforms to pylint/pep8 ([`47e0fe3`](https://github.com/icecube/voka/commit/47e0fe33b3dcd0f5adee4ec5bdd42bfafb89de06))

* make this script executable. ([`9091325`](https://github.com/icecube/voka/commit/909132554f5ca7cd546cf4df3924c0d26dd95722))

* removed example that&#39;s essentially duplicated in another script. ([`2d531e8`](https://github.com/icecube/voka/commit/2d531e8ddfdbad31cb74d0c788530b3fd06a4eea))

* mostly conforms to pylint/pep8.  just need to remove duplicate code, which likely amounts to removing redundant sripts. ([`15767ef`](https://github.com/icecube/voka/commit/15767ef7ee2357863c8f7083e6006e2514ad437e))

* test modules now better conform to pylint. ([`2a9d420`](https://github.com/icecube/voka/commit/2a9d420d6b3d86b45ea0f57c0e4d44d65c7eb055))

* last of the metrics adapted to conform to pylint/pep8. ([`5e3fc09`](https://github.com/icecube/voka/commit/5e3fc09cdd4bc5fa01c3970d255d91d6a4697d05))

* fixed typo in KS name ([`1062bf3`](https://github.com/icecube/voka/commit/1062bf31a435ef3ea82d979c854d55ff7cf48afc))

* more robust check for valid inputs ([`a1e62ce`](https://github.com/icecube/voka/commit/a1e62cedfa9d22a1373cb4fa8fea63eb1def6d3c))

* some progress, but needs a little more work.  mostly whitespace and variable name changes to conform to pylint. ([`42942fa`](https://github.com/icecube/voka/commit/42942fad5d97664230ea78cc8bf1a3cb2ffb377e))

* conforms to pylint ([`27a0c27`](https://github.com/icecube/voka/commit/27a0c27b33fd28ba13147aea5ce9b1c3910a36b6))

* just style changes 10/10 on pylint ([`f28630f`](https://github.com/icecube/voka/commit/f28630f3aa7555558781aeb59e5cc4dcccf51f94))

* conforms to pylint standards ([`f4b5623`](https://github.com/icecube/voka/commit/f4b56239d6360fe95862e0479e04b4147bfd37e8))

* adapted test to new variable name. ([`4c62373`](https://github.com/icecube/voka/commit/4c6237382b74509aeb2b0ad999c151fd61dc215d))

* a little cleaner, but still need to choose better variable names.  the ones from the paper aren&#39;t going to cut it. ([`bc363ae`](https://github.com/icecube/voka/commit/bc363aec9a7c6586c4686842c059a0c7eff6f15a))

* cleanup to conform to pylint. ([`d0c1f76`](https://github.com/icecube/voka/commit/d0c1f768d5bf6ec46c2553b26545b736578164e6))

* added docs and improved comments 10/10 via pylint ([`700ba64`](https://github.com/icecube/voka/commit/700ba64909bcaed4366739311cc50e0b91d4deab))

* updated README to include a coverage report. ([`e36c6f3`](https://github.com/icecube/voka/commit/e36c6f3baa39ea8d626f5f1284f2d803459b0313))

* tests are discoverable now and can be run via &#39;python3 -m unittest&#39; ([`6bc4d3f`](https://github.com/icecube/voka/commit/6bc4d3f55a70c81a6d128f168f478601fbac9a71))

* made tests executable ([`7880f06`](https://github.com/icecube/voka/commit/7880f0691d9546da7267c3dd8380d23465e8b2d3))

* updated the basic example script ([`d79da20`](https://github.com/icecube/voka/commit/d79da204e761fb6f0e81910612a46315eecf0df7))

* Merge branch &#39;master&#39; of github.com:IceCubeOpenSource/voka ([`7c027a0`](https://github.com/icecube/voka/commit/7c027a018671fc3e7d13d9db4bd78fad68d6eb50))

* commit early.  commit often. ([`1c83734`](https://github.com/icecube/voka/commit/1c837341fe2e7383be07c28e662c9deb2736390a))

* Update README.md ([`8e9dc72`](https://github.com/icecube/voka/commit/8e9dc72926485f874c0167787b4ac7826e804c81))

* added example scripts ([`c5bd0f9`](https://github.com/icecube/voka/commit/c5bd0f9ca5e21be7be7264826c23a32e48f0f091))

* Merge branch &#39;master&#39; of https://github.com/IceCubeOpenSource/voka ([`ff06f6e`](https://github.com/icecube/voka/commit/ff06f6edc35bdd66eed7a5a09a1b18947a40f7a1))

* added an example script that illustrates the downside of traditional statistical methods. ([`58ceb87`](https://github.com/icecube/voka/commit/58ceb874af74cca3ffecbb2dd65de54eb1f90f65))

* Update README.md ([`2352181`](https://github.com/icecube/voka/commit/2352181c4598fea99e23f26bea728e78ea4e92f8))

* Update README.md ([`d300d53`](https://github.com/icecube/voka/commit/d300d533b5da5060c0f7f00ae853dff6d4a9e06e))

* Update README.md ([`064d58f`](https://github.com/icecube/voka/commit/064d58f6e235bbcc4925a62570e63793c61e4d98))

* Update README.md ([`5ef3126`](https://github.com/icecube/voka/commit/5ef3126ca77e4ee893667f937b868969b99a1c75))

* Update README.md

Slight tweak to our public name.  Dropping &#34;South Pole&#34; ([`f9a649d`](https://github.com/icecube/voka/commit/f9a649d79d7a97a5e8613c78fb0f038d063400f7))

* Update README.md

Use more catchy keywords in the title. ([`ce035b2`](https://github.com/icecube/voka/commit/ce035b2255e8ec4d21a7f6f924f898149352946d))

* use only the shortened name.  i don&#39;t to ever have to deal with lawyers from warner brothers, ridley scott, or philip k. dick. ([`2b0097e`](https://github.com/icecube/voka/commit/2b0097e900b86d54fb49c90b282831c1db74f258))

* Update README.md ([`3dacad3`](https://github.com/icecube/voka/commit/3dacad3db29918b51971e38f814d4aec11c14ff9))

* Update README.md

Included the first draft of an abstract I plan to submit to SC20. ([`0211ef1`](https://github.com/icecube/voka/commit/0211ef17156330518e60713f7736dbf377953987))

* Merge pull request #2 from aolivas/master

Merge back to the Open Source repo. ([`acc8073`](https://github.com/icecube/voka/commit/acc8073ae8678b80f8bbc366a2e233bd9d2f9a98))

* updated the README file...not by much.  there&#39;s a lot more to come. ([`85d4120`](https://github.com/icecube/voka/commit/85d41200c22ad5ba5d08917e106caf05edf6a6df))

* added an example script ([`fa16770`](https://github.com/icecube/voka/commit/fa16770e43e439f39f94175d3f9c367929089860))

* added a method to calculate thresholds on the fly given the benchmark reference set ([`bfc44d1`](https://github.com/icecube/voka/commit/bfc44d17db2320310d3765e96f02d1186a29131d))

* add a requirements file to ease installations. ([`044355c`](https://github.com/icecube/voka/commit/044355cac2219b172859cd880a707ea09ba7580d))

* ignore any python virtual environments ending in _venv ([`3bafa6c`](https://github.com/icecube/voka/commit/3bafa6cdde729dd1fbdfc3eae4365933ef39abb6))

* Merge pull request #1 from aolivas/master

Test pass all the way up to VoightKampff ([`d1c2866`](https://github.com/icecube/voka/commit/d1c2866fc23e0c20271e6450e4e727fb628700a8))

* enabled a test condition.  just one for now. ([`afedd4e`](https://github.com/icecube/voka/commit/afedd4e54bde85c89adacfd07f66edd0aa12a3ea))

* added test for voight_kampff ([`c290f3d`](https://github.com/icecube/voka/commit/c290f3d7757c5793621d8ad5408ff23cf56f9e21))

* ignore emacs backup files ([`501bd8c`](https://github.com/icecube/voka/commit/501bd8c5c100ca9c2acc794ca258a10646408488))

* add LOF tests and made a few py3 fixes. ([`67a84ea`](https://github.com/icecube/voka/commit/67a84eace731c357a8f6f76812fd29a4d4728a54))

* tests pass.  need to be clear that the expected input is a series of non-negative real numbers (e.g. histogram bin values). ([`e527356`](https://github.com/icecube/voka/commit/e5273562985c7c45c0303722af4a4d8b38c165aa))

* initial commit ([`d8f3cc1`](https://github.com/icecube/voka/commit/d8f3cc117db69ff5d46c21527d99109086df9d89))

* Initial commit ([`eb6bfc0`](https://github.com/icecube/voka/commit/eb6bfc053789ef6698f6b7529eba4022f05cbdd4))
